==> haskell-chell-quickcheck-0.2.5.2-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.2
id: chell-quickcheck-0.2.5.2-D0L5gg6N4gK7iHjwdAUMzD
key: chell-quickcheck-0.2.5.2-D0L5gg6N4gK7iHjwdAUMzD
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: QuickCheck support for the Chell testing library
description:
    QuickCheck support for the <https://hackage.haskell.org/package/chell Chell> testing library.
category: Testing
abi: d5b610cc2413caa4a75dbba7fe8691e9
exposed: True
exposed-modules:
    Test.Chell.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-quickcheck-0.2.5.2
hs-libraries: HSchell-quickcheck-0.2.5.2-D0L5gg6N4gK7iHjwdAUMzD
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    chell-0.5-9UWUMeehunf2H8z3P3Mj4g random-1.1-3ypV4EIycgb35PKjTYYr5q
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.2
id: chell-quickcheck-0.2.5.2-CDW8lkKxiOOGec52PVxS6p
key: chell-quickcheck-0.2.5.2-CDW8lkKxiOOGec52PVxS6p
license: MIT
maintainer: Chris Martin, Julie Moronuki
author: John Millikin <john@john-millikin.com>
homepage: https://github.com/typeclasses/chell
synopsis: QuickCheck support for the Chell testing library
description:
    QuickCheck support for the <https://hackage.haskell.org/package/chell Chell> testing library.
category: Testing
abi: 89058c61cb4613b8e27764a5ab83d46f
exposed: True
exposed-modules:
    Test.Chell.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/chell-quickcheck-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/chell-quickcheck-0.2.5.2
hs-libraries: HSchell-quickcheck-0.2.5.2-CDW8lkKxiOOGec52PVxS6p
depends:
    QuickCheck-2.13.1-NoI9FBLINF1hoOq3Jp2mP base-4.12.0.0
    chell-0.5-HBBVh0kuv2x5hKcNiXPL5Z random-1.1-3ypV4EIycgb35PKjTYYr5q
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
